/*----------タイヤ制御（モータ制御）----------                 
 * 【使用方法】
 *  プログラムで進みたい方向を指定する。
 *  停止の命令を出すまで指示された動作を行う。
 *  速度はロボットの調整器をドライバーで調整する。
 *  
 *  ※プログラムで速度を制御する場合は3つ目の引数パラメータを指定する。
 *  
 * 【命令】
 *  hasiru( モータの左右 , 動作内容);
 *             |         +-------->   前に進む:mae
 *             |                      後ろに下がる:usiro
 *             |                      ブレーキ:teisi
 *             |                      空回り:OFF
 *             |
 *             +------------------>   両方のモータ:sayuu           
 *                                    右側のモータ:migi           
 *                                    左側のモータ:hidari
 *  
 * 【命令サンプル】
 *  すすむ    >> hasiru(sayuu, mae);
 *  バック    >> hasiru(sayuu, usiro);
 *  ブレーキ  >> hasiru(sayuu, teisi);
 *  空回り    >> hasiru(sayuu, OFF);
 *  右曲がり  >> hasiru(migi, mae);
 *  左曲がり　>> hasiru(hidari, mae); 
 *  右まわり  >> hasiru(migi, usiro); 
 *             hasiru(hidari, mae);
 *  左まわり  >> hasiru(migi, mae);
 *             hasiru(hidari, usiro);
 *  右バック  >> hasiru(migi, usiro);
 *  左バック  >> hasiru(hidari, usiro);
 *  
 *  ※プログラム内で速度制御する場合
 *  hasiru( 左右, 動作モード, 速度(0～255) );
 */


 
void hasiru(unsigned char active_MOTOR, unsigned char move_mode){
  if(active_MOTOR == sayuu){
    switch(move_mode){
        case mae:
          digitalWrite( MOTOR_SIG_A1, HIGH);
          digitalWrite( MOTOR_SIG_A2, LOW);
          digitalWrite( MOTOR_SIG_B1, HIGH);
          digitalWrite( MOTOR_SIG_B2, LOW);
          break;
        case usiro:
          digitalWrite( MOTOR_SIG_A1, LOW);
          digitalWrite( MOTOR_SIG_A2, HIGH);
          digitalWrite( MOTOR_SIG_B1, LOW);
          digitalWrite( MOTOR_SIG_B2, HIGH);
          break;
        case teisi:
          digitalWrite( MOTOR_SIG_A1, HIGH);
          digitalWrite( MOTOR_SIG_A2, HIGH);
          digitalWrite( MOTOR_SIG_B1, HIGH);
          digitalWrite( MOTOR_SIG_B2, HIGH);
          break;
        case OFF:
          digitalWrite( MOTOR_SIG_A1, LOW);
          digitalWrite( MOTOR_SIG_A2, LOW);
          digitalWrite( MOTOR_SIG_B1, LOW);
          digitalWrite( MOTOR_SIG_B2, LOW);
          break;
        default:
          digitalWrite( MOTOR_SIG_A1, LOW);
          digitalWrite( MOTOR_SIG_A2, LOW);
          digitalWrite( MOTOR_SIG_B1, LOW);
          digitalWrite( MOTOR_SIG_B2, LOW);
          break;
     }
    analogWrite(MOTOR_SIG_APWM , analogRead(VARIABLE_RES2)/4);
    analogWrite(MOTOR_SIG_BPWM , analogRead(VARIABLE_RES1)/4);
  }
  else if(active_MOTOR == migi){
    switch(move_mode){
      case mae:
        digitalWrite( MOTOR_SIG_A1, HIGH);
        digitalWrite( MOTOR_SIG_A2, LOW);
        digitalWrite( MOTOR_SIG_B1, LOW);
        digitalWrite( MOTOR_SIG_B2, LOW);
        break;
      case usiro:
        digitalWrite( MOTOR_SIG_A1, LOW);
        digitalWrite( MOTOR_SIG_A2, HIGH);
        digitalWrite( MOTOR_SIG_B1, LOW);
        digitalWrite( MOTOR_SIG_B2, LOW);
        break;
      case teisi:
        digitalWrite( MOTOR_SIG_A1, HIGH);
        digitalWrite( MOTOR_SIG_A2, HIGH);
        digitalWrite( MOTOR_SIG_B1, LOW);
        digitalWrite( MOTOR_SIG_B2, LOW);
        break;
      case OFF:
        digitalWrite( MOTOR_SIG_A1, LOW);
        digitalWrite( MOTOR_SIG_A2, LOW);
        digitalWrite( MOTOR_SIG_B1, LOW);
        digitalWrite( MOTOR_SIG_B2, LOW);
        break;
      default:
        digitalWrite( MOTOR_SIG_A1, LOW);
        digitalWrite( MOTOR_SIG_A2, LOW);
        digitalWrite( MOTOR_SIG_B1, LOW);
        digitalWrite( MOTOR_SIG_B2, LOW);
        break;
    }
    analogWrite(MOTOR_SIG_APWM , analogRead(VARIABLE_RES2)/4);
  }
  else if(active_MOTOR == hidari){
    switch(move_mode){
      case mae:
        digitalWrite( MOTOR_SIG_A1, LOW);
        digitalWrite( MOTOR_SIG_A2, LOW);
        digitalWrite( MOTOR_SIG_B1, HIGH);
        digitalWrite( MOTOR_SIG_B2, LOW);
        break;
      case usiro:
        digitalWrite( MOTOR_SIG_A1, LOW);
        digitalWrite( MOTOR_SIG_A2, LOW);
        digitalWrite( MOTOR_SIG_B1, LOW);
        digitalWrite( MOTOR_SIG_B2, HIGH);
        break;
      case teisi:
        digitalWrite( MOTOR_SIG_A1, LOW);
        digitalWrite( MOTOR_SIG_A2, LOW);
        digitalWrite( MOTOR_SIG_B1, HIGH);
        digitalWrite( MOTOR_SIG_B2, HIGH);
        break;
      case OFF:
        digitalWrite( MOTOR_SIG_A1, LOW);
        digitalWrite( MOTOR_SIG_A2, LOW);
        digitalWrite( MOTOR_SIG_B1, LOW);
        digitalWrite( MOTOR_SIG_B2, LOW);
        break;
      default:
        digitalWrite( MOTOR_SIG_A1, LOW);
        digitalWrite( MOTOR_SIG_A2, LOW);
        digitalWrite( MOTOR_SIG_B1, LOW);
        digitalWrite( MOTOR_SIG_B2, LOW);
        break;      
    }
    analogWrite(MOTOR_SIG_BPWM , analogRead(VARIABLE_RES1)/4);
  }
  else{
    digitalWrite( MOTOR_SIG_A1, LOW);
    digitalWrite( MOTOR_SIG_A2, LOW);
    digitalWrite( MOTOR_SIG_B1, LOW);
    digitalWrite( MOTOR_SIG_B2, LOW);   
    analogWrite(MOTOR_SIG_APWM , 0);
    analogWrite(MOTOR_SIG_BPWM , 0);
  }
}
void hasiru(unsigned char active_MOTOR, unsigned char move_mode, unsigned char MOTOR_speed){
    if(active_MOTOR == sayuu){
    switch(move_mode){
        case mae:
          digitalWrite( MOTOR_SIG_A1, HIGH);
          digitalWrite( MOTOR_SIG_A2, LOW);
          digitalWrite( MOTOR_SIG_B1, HIGH);
          digitalWrite( MOTOR_SIG_B2, LOW);
          break;
        case usiro:
          digitalWrite( MOTOR_SIG_A1, LOW);
          digitalWrite( MOTOR_SIG_A2, HIGH);
          digitalWrite( MOTOR_SIG_B1, LOW);
          digitalWrite( MOTOR_SIG_B2, HIGH);
          break;
        case teisi:
          digitalWrite( MOTOR_SIG_A1, HIGH);
          digitalWrite( MOTOR_SIG_A2, HIGH);
          digitalWrite( MOTOR_SIG_B1, HIGH);
          digitalWrite( MOTOR_SIG_B2, HIGH);
          break;
        case OFF:
          digitalWrite( MOTOR_SIG_A1, LOW);
          digitalWrite( MOTOR_SIG_A2, LOW);
          digitalWrite( MOTOR_SIG_B1, LOW);
          digitalWrite( MOTOR_SIG_B2, LOW);
          break;
        default:
          digitalWrite( MOTOR_SIG_A1, LOW);
          digitalWrite( MOTOR_SIG_A2, LOW);
          digitalWrite( MOTOR_SIG_B1, LOW);
          digitalWrite( MOTOR_SIG_B2, LOW);
          break;
     }
    analogWrite(MOTOR_SIG_APWM , analogRead(MOTOR_speed));
    analogWrite(MOTOR_SIG_BPWM , analogRead(MOTOR_speed));
  }
  else if(active_MOTOR == migi){
    switch(move_mode){
      case mae:
        digitalWrite( MOTOR_SIG_A1, HIGH);
        digitalWrite( MOTOR_SIG_A2, LOW);
        digitalWrite( MOTOR_SIG_B1, LOW);
        digitalWrite( MOTOR_SIG_B2, LOW);
        break;
      case usiro:
        digitalWrite( MOTOR_SIG_A1, LOW);
        digitalWrite( MOTOR_SIG_A2, HIGH);
        digitalWrite( MOTOR_SIG_B1, LOW);
        digitalWrite( MOTOR_SIG_B2, LOW);
        break;
      case teisi:
        digitalWrite( MOTOR_SIG_A1, HIGH);
        digitalWrite( MOTOR_SIG_A2, HIGH);
        digitalWrite( MOTOR_SIG_B1, LOW);
        digitalWrite( MOTOR_SIG_B2, LOW);
        break;
      case OFF:
        digitalWrite( MOTOR_SIG_A1, LOW);
        digitalWrite( MOTOR_SIG_A2, LOW);
        digitalWrite( MOTOR_SIG_B1, LOW);
        digitalWrite( MOTOR_SIG_B2, LOW);
        break;
      default:
        digitalWrite( MOTOR_SIG_A1, LOW);
        digitalWrite( MOTOR_SIG_A2, LOW);
        digitalWrite( MOTOR_SIG_B1, LOW);
        digitalWrite( MOTOR_SIG_B2, LOW);
        break;
    }
    analogWrite(MOTOR_SIG_APWM , analogRead(MOTOR_speed));
  }
  else if(active_MOTOR == hidari){
    switch(move_mode){
      case mae:
        digitalWrite( MOTOR_SIG_A1, LOW);
        digitalWrite( MOTOR_SIG_A2, LOW);
        digitalWrite( MOTOR_SIG_B1, HIGH);
        digitalWrite( MOTOR_SIG_B2, LOW);
        break;
      case usiro:
        digitalWrite( MOTOR_SIG_A1, LOW);
        digitalWrite( MOTOR_SIG_A2, LOW);
        digitalWrite( MOTOR_SIG_B1, LOW);
        digitalWrite( MOTOR_SIG_B2, HIGH);
        break;
      case teisi:
        digitalWrite( MOTOR_SIG_A1, LOW);
        digitalWrite( MOTOR_SIG_A2, LOW);
        digitalWrite( MOTOR_SIG_B1, HIGH);
        digitalWrite( MOTOR_SIG_B2, HIGH);
        break;
      case OFF:
        digitalWrite( MOTOR_SIG_A1, LOW);
        digitalWrite( MOTOR_SIG_A2, LOW);
        digitalWrite( MOTOR_SIG_B1, LOW);
        digitalWrite( MOTOR_SIG_B2, LOW);
        break;
      default:
        digitalWrite( MOTOR_SIG_A1, LOW);
        digitalWrite( MOTOR_SIG_A2, LOW);
        digitalWrite( MOTOR_SIG_B1, LOW);
        digitalWrite( MOTOR_SIG_B2, LOW);
        break;      
    }
    analogWrite(MOTOR_SIG_BPWM , analogRead(MOTOR_speed));
  }
  else{
    digitalWrite(MOTOR_SIG_A1, LOW);
    digitalWrite(MOTOR_SIG_A2, LOW);
    digitalWrite(MOTOR_SIG_B1, LOW);
    digitalWrite(MOTOR_SIG_B2, LOW);   
    analogWrite(MOTOR_SIG_APWM , 0);
    analogWrite(MOTOR_SIG_BPWM , 0);
  }
}
